package crawler;

import java.util.Hashtable;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import outputFormat.AsosProduct;
import outputFormat.LVProduct;
import utility.ExcelManager;
import utility.SiteManager;

public class EluxuryCrawler {
	
	//file to write the output on
	private static String outputFile = "excelfile/lv.xls";
	//site url
	private static String siteurl = "http://www.eluxury.com";
	//base url
	private static String baseurl = "http://www.eluxury.com/estore/brands/louis_vuitton/w05/";
	//page to start crawl content
	private static String startpage1 = "http://www.eluxury.com/estore/brands/louis_vuitton/w05/collection.jsp?catId=cat20427&brand=3250";
	private static String startpage2 = "http://www.eluxury.com/estore/brands/louis_vuitton/w05/collection.jsp?catId=cat20429&brand=3250";
	//gender of the product 
	private static String gender;
	//image file save to fold
	private static String imgFold = "LV/";
	
	private static String brand = "Louis Vuitton";
	
	private static String priceUnit = "USD";
	
	private static int prodCount = 0;
	private static int startpos = 276; //714 for women
	// main to start crawler 
	public static void main(String[] args){
		LVProduct lv = new LVProduct();
		ExcelManager.prepareFile(outputFile, lv);	
//		gender = "women";
//		crawlContent(startpage1);
		gender = "men";
		crawlContent(startpage2);
	}

	private static void crawlContent(String url) {
		//Category list to crawl content on each
		Hashtable<String, String> categories = new Hashtable<String, String>();
		
		//save the page to a String
		String doc = SiteManager.getDocumentFromURL(url, "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)");
		
		//find current category name 
		Pattern cateP = Pattern.compile("<span class=\"leftNavSubCategoryListOn\">([^<]*?)</span>");
		Matcher cateM = cateP.matcher(doc);
		while(cateM.find()){
			String cateName = cateM.group(1);
//			System.out.println("-------------------------------------------------------------------");
			System.out.println("Current category: "+cateName);
//			System.out.println("-------------------------------------------------------------------");
			categories.put(cateName, url);
		}
		
		
		//find other category
		cateP = Pattern.compile("<a href=\"([^\"]*?)\" class=\"leftNavSubCategoryListOff\">([^<]*?)</a>");
		cateM = cateP.matcher(doc);
		while(cateM.find()){
			String cateURL = cateM.group(1);
			cateURL = urlCorrection(cateURL, baseurl);
			String cateName = cateM.group(2);
//			System.out.println("-------------------------------------------------------------------");
			System.out.println("Current category: "+cateName + " URL: "+cateURL);
//			System.out.println("-------------------------------------------------------------------");
			categories.put(cateName, cateURL);
		}
		
		//for each category crawl content find different styles
		for(String cateName : categories.keySet()){
//			System.out.println("-------------------------------------------------------------------");
			findStyle(cateName, categories.get(cateName));
//			System.out.println("-------------------------------------------------------------------");
		}
	}

	
	private static void findStyle(String cateName, String cateURL) {
//		System.out.println(cateName+ " : " + cateURL);
			
		//save the page to a String
		String doc = SiteManager.getDocumentFromURL(cateURL, "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)");
		
		//find styles
		Pattern styleP = Pattern.compile("<a href=\"([^\"]*?)\" class=\"mainSubSubCategoryListOff\" onmouseout=\"([^\"]*?)\" onmouseover=\"([^\"]*?)\">([^>]*?)</a>");
		Matcher styleM = styleP.matcher(doc);
		while(styleM.find()){
			String styleName = styleM.group(4);
			String styleURL = styleM.group(1);
			styleURL = urlCorrection(styleURL, baseurl);
			System.out.println("Style name: "+styleName+" Style url: " + styleURL);
//			System.out.println("-------------------------------------------------------------------");
			findProduct(cateName, styleName, styleURL);
//			System.out.println("-------------------------------------------------------------------");
		}
	}
	
	private static void findProduct(String cateName, String styleName, String styleURL) {
		//save the page to a String
		String doc = SiteManager.getDocumentFromURL(styleURL, "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)");
		
		//find products
		Pattern productP = Pattern.compile("<a href=\"([^\"]*?)\" class=\"mainProductListOff\" onmouseover=\"([^\"]*?)\">([^>]*?)</a>");
		Matcher productM = productP.matcher(doc);
		while(productM.find()){
			String productName = productM.group(3);
			String productURL = productM.group(1);
			productURL = urlCorrection(productURL, siteurl);
			System.out.println("-------------------------------------------------------------------");
//			System.out.println("Product name: " + productName + "  product url: "+productURL);
			crawlProduct(cateName, styleName, productName, productURL);
			System.out.println("-------------------------------------------------------------------");
		}
		
		//find next page
		Pattern nextP = Pattern.compile("<a href=\"([^\"]*?)\" class=\"mainPageLinkOff\"><img width=\"10\" height=\"23\" src=\"/estore/assets_server/global/buttons/btn_next.gif\" border=\"0\"></img></a>");
		Matcher nextM = nextP.matcher(doc);
//		System.out.println("Finding next page!");
//		System.out.println(doc);
		while(nextM.find()){
			String pageurl = nextM.group(1);
			pageurl = urlCorrection(pageurl, siteurl);
//			System.out.println("Next page: "+pageurl);
			findProduct(cateName, styleName, pageurl);
		}
//		System.out.println("Find next page end!");
	}

	private static void crawlProduct(String cateName, String styleName,String productName, String productURL) {
		System.out.println("productCount: "+prodCount+"---------------------");
		if(startpos <= prodCount){
		System.out.println(LVProduct.idCount+" : "+productURL);
		System.out.println("\n\n\n");
		//save the page to a String
		String doc = SiteManager.getDocumentFromURL(productURL, "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1)");
		// 	System.out.print(doc);
//		Pattern nameP = Pattern.compile("<td class=\"desc\"><span>([^<]*?)</span></td>");
//		Matcher nameM = nameP.matcher(doc);
//		Pattern priceP = Pattern.compile("<td class=\"price\">\\$([^<]*?)</td>");
//		Matcher priceM = priceP.matcher(doc);
		Pattern imageP = Pattern.compile("<img(.*?)class=\"bigprod\" src=\"([^\"]*?)\"([^>]*?)>");
		Matcher imageM = imageP.matcher(doc);
		Pattern descP = Pattern.compile("<td class=\"tabresult\"><span>" +
										"([^>]*?)(<ul>((\\s*?)<li>([^>]*?)</li>(\\s*?))*?</ul>)?([^>])*?</span><span class=\"pdDesc\"></span></td>");
		Matcher descM = descP.matcher(doc);
		while(imageM.find() && descM.find()){
			String name = productName.substring(0, productName.indexOf(","));
			String price = productName.substring(productName.indexOf("$")+1);
			String image = imageM.group(2);
			String desc = descM.group(1)+descM.group(2);
			try {
				image = SiteManager.saveImage(image, imgFold, LVProduct.idCount);
			} catch (Exception e) {
				e.printStackTrace();
			}
			System.out.println("Product name: "+name+" price: "+price+" image: "+image+" desc: "+desc);
			LVProduct lv = new LVProduct(name, image, brand, price, priceUnit, gender, desc, cateName, styleName, productURL);
			ExcelManager.writeToFile(lv);
		}
		System.out.println("\n\n\n");
		}
		prodCount++;
	}

	private static String urlCorrection(String url, String preurl){
		url = preurl + url;
		url = url.substring(0,url.indexOf(";"))+ url.substring(url.indexOf("?"));
		url = url.replaceAll("amp;", "");
		return url;
	}
}
